/**
 * (c) 2002 Zyneo
 *
 * $Id: Receive2.java,v 1.3 2003/03/27 16:35:05 nian Exp $
 *
 * <pre>
 *
 * $Log: Receive2.java,v $
 * Revision 1.3  2003/03/27 16:35:05  nian
 * Added print of to
 *
 * Revision 1.2  2003/03/19 16:14:18  nian
 * Corrected some comments
 *
 * Revision 1.1  2002/10/15 07:37:23  nian
 * Added file
 *
 *
 * </pre>
 */
package zyneo.sms.test.xml.tcp;

import org.apache.log4j.*;

import zyneo.sms.gateway.adaptor.xml.tcp.client.*;
import zyneo.sms.*;

import java.io.*;
import java.net.*;
import java.text.*;

/**
 * Receives SMS-messages and status reports by
 * using the RequestServer.
 *
 * @author Niklas Andersson
 */
public class Receive2 implements iReceiveClient
{
  public static final String DEFAULT_HOST = "localhost";
  public static final int DEFAULT_PORT = 3001;

  protected Category m_log;

  protected String m_host;
  protected int m_port;

  SimpleDateFormat m_sdf;

  /**
   * Constructor
   *
   * @param port
   * @param host
   */
  public Receive2(int port,String host)
  {
    BasicConfigurator.configure();

    m_sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    m_log = Category.getInstance(this.getClass());

    if(port < 1)
      m_port = DEFAULT_PORT;
    else
      m_port = port;

    if(host == null || "".equals(host) )
      m_host = DEFAULT_HOST;
    else
      m_host = host;
  }

  public void run()
    throws IOException,UnknownHostException
  {
    // Create the Socket
    ReceiveServer rs = new ReceiveServer(this,new Socket(m_host,m_port),m_log);

    // Disable connection timeout
    rs.setConnectionIdle(0);

    // Set a big Frame delay
    rs.setFrameDelay(5000);

    // And, lets run
  	m_log.info("Waiting for messages");
    rs.run();
  }
  
  /**
   * This method is called by the ReceiveServer
   * whenever a Sms arrives. If the implementation
   * of this method throws an exception, the Receive-
   * Server will "nak" the Sms. the Sms will be considered
   * by the SmsGateway as not delivered and saved for future
   * delivery attempts.
   *
   * @param s The sms
   *
   * @exception Exception, Specified by implementor.
   */
  public void receive(Sms s)
    throws Exception
  {
    m_log.info("-==SMS-Start==-");
    m_log.info("From:" + s.getFrom());
    String to = s.getTo();
    if(to != null && !"".equals(to))
  		m_log.info("To:" + to);
  	else
  		m_log.info("To:");
  		
    m_log.info("Message:" + s.getMessage());
    m_log.info("At:" + m_sdf.format(s.getTime()));
    m_log.info("-==SMS-End==-");
  }

  /**
   * This method is called by the ReceiveServer
   * whenever a Notification arrives. If the implementation
   * of this method throws an exception, the Receive-
   * Server will "nak" the Notification. The Notification will
   * be considered by the SmsGateway as not delivered and saved
   * for future delivery attempts.
   *
   * @param n The notification
   *
   * @exception Exception, Specified by implementor.
   */
  public void receive(Notification n)
    throws Exception
  {
    m_log.info("-==Notification-Start==-");

    m_log.info("ID:" + n.getId());
    m_log.info("Type:" + n.getType());
    if(n.getSMSCDate() != null)
      m_log.info("SMSC-Date:" + m_sdf.format(n.getSMSCDate()));

    if(n.getProviderDate() != null)
      m_log.info("Provider-Date:" + m_sdf.format(n.getProviderDate()));

    if(n.getDischargeDate() != null)
      m_log.info("Event-Date:" + m_sdf.format(n.getDischargeDate()));

    m_log.info("-==Notification-End==-");
  }

  /**
   * This method is called when the ReceiveServer
   * terminates.
   */
  public void exit()
  {
    m_log.info("Terminating");
  }

  public static void main(String[] args)
  {
    try
    {
      Receive2 r = null;
      if(args.length == 0)
      {
        r = new Receive2(-1,null);
        r.run();
      }
      else if(args.length == 1)
      {
        r = new Receive2(Integer.parseInt(args[0]),null);
        r.run();
      }
      else if(args.length == 2)
      {
        r = new Receive2(Integer.parseInt(args[0]),args[1]);
        r.run();
      }
      else
        System.out.println("Usage: [port] [host]");
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }
  }
}