import xml.parsers.expat
from protocol.Sms import *
from protocol.Notification import *
from base.Logger import *

class Request:

    """
        $Id: Request.py,v 1.1.1.1 2003/04/10 14:38:57 maro Exp $
        
        Interprets an XML request by parsing the XML and depending on
        type will return either an SMS or a Notification object

        @author maro
    """

    # Constants
    SMS = "sms"
    NOTIFICATION = "not"

    m_raw_data = None
    m_current_tag = None
    m_type = None
    m_request = None
    m_log = None
    m_message = ""

    def __init__(self, request):
        """Constructs the request by parsing the xml in 'request'"""
        self.m_log = Logger()
        self.m_raw_data = request
        self.doParse()

    def doParse(self):
        """Parses the XML-request from the gateway"""
        # Create parser
        self.m_log.logDebug("Parsing: \n%s" % self.m_raw_data)
        parser = xml.parsers.expat.ParserCreate()
        parser.StartElementHandler = self.startElement
        parser.EndElementHandler = self.endElement
        parser.CharacterDataHandler = self.characters
        # Parse
        parser.Parse(self.m_raw_data)

    def getRawData(self):
        """Returns the raw data representing the request (xml)"""
        return self.m_raw_data

    def getType(self):
        """Returns the type of request, see constants SMS and NOTIFICATION"""
        return self.m_type

    def getRequest(self):
        """Returns the request, which could either be an Sms or a Notification"""
        return self.m_request

    # --- DocumentHandler methods

    def characters(self, data):
        """Handle a character data event.
        The data are contained in the substring of ch
        starting at position start and of length length."""
        if ( self.m_type == self.SMS ):
            if ( self.m_current_tag == "message" ):
                # Data could be appended several times, add it to a temporary
                # variable for now. Taken care of in endElement.
                self.m_message += data

    def endElement(self, name):
        """Handle an event for the end of an element. In case of 'message' set
           the message text.
        """
        if ( self.m_current_tag == "message" ):
            self.m_request.setUnicodeText(self.m_message)
        self.m_current_tag = None

    def startElement(self, name, atts):
        """Handle an event for the beginning of an element.
        atts is an object of type AttributeList."""
        self.m_current_tag = name
        if ( name == "sms" ):
            self.m_type = self.SMS
            self.m_request = Sms()
        elif ( name == "notification" ):
            self.m_type = self.NOTIFICATION
            self.m_request = Notification()
        self.parseAttributes(atts)


    def parseAttributes(self, attrs):
        if ( self.m_type == self.SMS ):
            if ( self.m_current_tag == "to" ):
                self.m_request.setRecipient(attrs["address"])
            elif ( self.m_current_tag == "from" ):
                self.m_request.setOriginator(attrs["address"])
            elif ( self.m_current_tag == "receive" ):
                self.m_request.setDelivered(attrs["date"])
        elif ( self.m_type == self.NOTIFICATION ):
            if ( self.m_current_tag == "message-id" ):
                self.m_request.setMessageId(attrs["value"])
            elif ( self.m_current_tag == "type" ):
                self.m_request.setNotificationType(attrs["value"])
            elif ( self.m_current_tag == "provider" ):
                self.m_request.setProviderDate(attrs["date"])
