<?php

    //
    // Copyright (c) 2002-2003 Zyneo HB. (http://www.zyneo.com)
    // See LICENSE distributed with this package for more information.
    //

    include_once (_DOCROOT . "/base/Base.php");

    /**
     * $Id: Sms.php,v 1.1.1.1 2003/03/27 10:27:42 maro Exp $
     *
     * This class represents an SMS.
     * 
     * Use getter methods to retrieve information about the message.
     * @package adapter.protocol
     * @author Magnus Rosenquist, Zyneo
     */    
    class Sms
        extends Base
    {
        var $STATUS_REPORT_YES = "true";
        var $STATUS_REPORT_NO  = "false";
        
        /** SMS from, originator of message */
        var $__from;
        /** SMS recipient */
        var $__to;
        /** SMS text */
        var $__message;
        /** If status reporting for this message is wanted, string ("true"/"false") */
        var $__statusReporting;
        /** Specifies the date when the SMSc should stop try to deliver the 
         * message. [yyyy-mm-dd hh:mm:ss] 
         */
        var $__validTo;
        /** Date reported by the SMSc when the SMS was delivered
         * Format [yyyy-mm-dd hh:mm:ss]
         */
        var $__delivered;
        
        /**
         * Creates a new Sms object with a default to-address (recipient)
         * and a message to be sent.
         * Statusreporting is by default set to 'false'. If statusreports are
         * required you have to set statusreporting to 'true'.
         * @param string $to mobilephonenumber (recipient)
         * @param string $message the message
         * @see setStatusReporting
         */
        function Sms ($to="", $message="")
        {
            $this->registerClass(get_class($this));
            $this->__to      = $to;
            $this->__message = $message;
            $this->__statusReporting = $this->STATUS_REPORT_NO;
        }
        
        /** 
         * Sets the recipient mobilephonenumber.
         * @param string $to the mobilephone number.
         */
        function setTo($to)                  { $this->__to = $to; }
        /**
         * Sets the originator mobilephonenumber. Note that the settings in the
         * gateway may override the originator.
         * @param string $from originator name or phone-number.
         */
        function setFrom($from)              { $this->__from = $from; }
        /**
         * Sets if Notifications should be returned for this SMS, defaults to 'false'.
         * Note that not all providers in the gateway can deliver status-reports.
         * Use params STATUS_REPORT_YES and STATUS_REPORT_NO to set valid status.
         * @param string $status true or false
         */
        function setStatusReporting($status) { $this->__statusReporting = $status; }
        /**
         * If the recipient is unreachable, the validTo date specifies how long
         * the SMSc should continue trying to deliver the SMS.
         * @param string $valid string representing a date formatted like 'yyyy-mm-dd hh:mm:ss'
         */
        function setValidTo($valid)          { $this->__validTo = $valid; }
        /**
         * Sets the date the SMS was delivered, only used by the gateway.
         * @param string $delivered string representing a date formatted like 'yyyy-mm-dd hh:mm:ss'
         */
        function setDelivered($delivered)    { $this->__delivered = $delivered; }
        /** 
         * Sets the text for this SMS.
         * @param string $message the SMS text.
         */
        function setMessage($message)        { $this->__message = $message; }
        
        // Getters
        
        /** 
         * Returns the recipient for this SMS 
         * @return string recipient
         */
        function getTo()              { return $this->__to; }
        /**
         * Returns the originator for this SMS.
         * @return string originator
         */
        function getFrom()            { return $this->__from; }
        /**
         * Returns the message-text for this SMS.
         * @return string message
         */
        function getMessage()         { return $this->__message; }
        /**
         * Returns the valid-to date for this message
         * @return string valid-to date
         */
        function getValidTo()         { return $this->__validTo; }
        /**
         * Returns 'true/false' if statusreporting is enabled for this SMS.
         * @return string 'true' or 'false'
         */
        function getStatusReporting() { return $this->__statusReporting; }
        /**
         * Returns the date the SMS was delivered to the gateway.
         * @return string date-delivered.
         */
        function getDelivered()       { return $this->__delivered; }

        function validateMobile()
        {
            $mob = $this->__to;
            if ( $mob != "" )
            {
            	$two = substr($mob, 0, 2);
                $first = substr($mob, 0, 1);
                if ( $first != "+" && $two != "00")
                    return false;
                else
                {
                    $rest = substr($mob,1);
                    if ( preg_match("/\D/", $rest) )
                        return false;
                    else
                        return true;
                }
            }
            else
                return false;
        }

        function validateMessage()
        {
            $msg = $this->__message;
            if ( $msg != "" )
            {
                if ( strlen($msg) > 160 )
                    return false;
                else
                    return true;
            }
            else
                return false;
        }

    }
?>
