<?php

    //
    // Copyright (c) 2002-2003 Zyneo HB. (http://www.zyneo.com)
    // See LICENSE distributed with this package for more information.
    //

    include_once (_DOCROOT ."/base/Base.php");

    /**
     * $Id: SendResponse.php,v 1.1.1.1 2003/03/27 10:27:42 maro Exp $
     *
     * This class represents a Response on a sent SMS message received from the
     * gateway.
     * @package adapter.protocol.send
     * @author Magnus Rosenquist, Zyneo
     */    
    class SendResponse
        extends Base
    {

        /** Constant for defining this Response as successful */
        var $STATUS_SUCCESS = "success";
        
        /** Constant for defining this Response as failed. */
        var $STATUS_FAIL    = "fail";
            
        /** Raw data representing the Response (XML) */
        var $__raw;
        /** Type of Response */
        var $__type;
        /** Message id for this Response */
        var $__messageId;
        /** Status of the Response */
        var $__status;
        /** Error code for the Response */
        var $__errorCode;
        /** Error message for the Response */
        var $__errorMsg;
        /** Current tag when processing the XML */
        var $__currentTag;
        
        /**
         * Creates a new SendResponse, if param $xml is provided the response
         * is parsed. If $xml is omitted, an empty SendResponse is created.
         * @param string $xml optional response from gateway.
         */
        function SendResponse($xml="")
        {
            $this->registerClass(get_class($this));
            $this->__errorCode = 0;
            if ( $xml != "" )
            {
                $this->__raw = $xml;
                $this->parse();
            }
        }
        
        /**
         * Returns the status of the response which is one of 
         * STATUS_SUCCESS or STATUS_FAIL.
         * @return string status
         */
        function getStatus()            
        { 
            $this->registerMethod("getStatus");
            if ( $this->__errorCode == 0 )
                return ( $this->STATUS_SUCCESS );
            else
                return ( $this->STATUS_FAIL );
        }
        
        /**
         * Returns the message-id for the message if successful send.
         * @return string
         */
        function getMessageId()         { return $this->__messageId; }
        /**
         * Returns the error-code for the message if unsuccessful send.
         * @return int
         */
        function getErrorCode()         { return $this->__errorCode; }
        /**
         * Returns the error-message for the message if unsuccessful send.
         * @return string
         */
        function getErrorMessage()      { return $this->__errorMsg; }
        /**
         * Returns the response-type for the sent message
         * @return string
         */
        function getResponseType()      { return $this->__type; }
        
        // Setters
        
        /**
         * Sets the response type for the message
         * @param string $type
         */
        function setResponseType($type) { $this->__type = $type; }
        /**
         * Sets the status of the response
         * @param string $status
         */
        function setStatus($status)     { $this->__status = $status; }
        /**
         * Sets the message-id for the message
         * @param string $id
         */
        function setMessageId($id)      { $this->__messageId = $id; }
        /**
         * Sets the error-code for the message in case of failure.
         * @param int code
         */
        function setErrorCode($code)    { $this->__errorCode = $code; }
        /**
         * Sets the error-message for the message in case of failure.
         * @param string $msg
         */
        function setErrorMessage($msg)  { $this->__errorMsg = $msg; }
        
        /**
         * Serializes the response into an XML string.
         * @return string 
         */
        function toXML()
        {
            $this->registerMethod("toXML");
            $xml  = "<?xml version=\"1.0\"?>";
            $xml .= "<response type=\"".$this->__type."\" version=\"1.0\">";
            if ( $this->__status == $this->STATUS_FAIL )
                $xml .= "<nak><error code=\"".$this->__errorCode."\">".$this->__errorMsg."</error></nak>";
            else if ( $this->__status == $this->STATUS_SUCCESS )
                $xml .= "<ack><message-id value=\"".$this->__messageId."\"></message-id></ack>";
            $xml .= "</response>";
            return $xml;
        }
        
        /**
         * Parses the response from the gateway.
         */
        function parse()
        {
            $this->registerMethod("parse");
            
            $parser = xml_parser_create("UTF-8");
            xml_set_object($parser, $this)
                or die ("Could not add callback");
            xml_parser_set_option($parser, XML_OPTION_CASE_FOLDING, false)
                or die ("Could not set option");
            xml_set_element_handler($parser, "startElement", "endElement")
                or die ("Could not add element handlers");
            xml_set_character_data_handler($parser, "characterData")
                or die ("Could not add data handler");
            //
            $result = xml_parse($parser, $this->__raw);
            if ( ! $result )
            {
                $this->logFatal("Could not parse response!");
                $this->logFatal("Code: " . xml_get_error_code($parser));
                $this->logFatal("Error: " . xml_error_string(xml_get_error_code($parser)));
                $this->logFatal("At: " . xml_get_current_line_number($parser));
            }
            xml_parser_free($parser);
        }
        
        function startElement($parser, $name, $attrs)
        {
            $this->__currentTag = $name;
            $this->parseAttributes($attrs);
        }
        
        function endElement($parser, $name)
        {
            $this->__currentTag = "";
        }
        
        function characterData($parser, $data)
        {
            if ( $this->__currentTag == "error" )
                $this->__errorMessage = $data;
        }
                    
        /**
         * Parses the attributes for the current tag
         */
        function parseAttributes($attrs)
        {
            if ( $this->__currentTag == "response" )
                $this->__type = $attrs["type"];
            if ( $this->__currentTag == "error" )
                $this->__errorCode = $attrs["code"];
            if ( $this->__currentTag == "message-id" )
                $this->__messageId = $attrs["value"];
        }
    
    }

?>
